import { Button, Popconfirm, Modal, Form, Input, message, Select } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import React, { useRef, useState } from 'react';
import moment from 'moment';
import PageTable from '@/components/PageTable';
import {
  getMachineryTypeList,
  addMachineryType,
  updateMachineryType,
  deleteMachineryType,
} from '@/services/machineryType';

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD') : '';
};
const FormItem = Form.Item;
const { Option } = Select;

export default (props) => {
  const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
  const [loading, setLoading] = useState(false);
  const [form] = Form.useForm();
  const actionRef = useRef();
  const [selectModal, setSelectModal] = useState(false);
  const [typeId, setTypeId] = useState();

  //列表切换分类状态方法
  const handleOK = (record, data) => {
    const title = record.status
      ? '您确定要将该分类状态变更为禁用吗? 禁用后该分类将不能录入农机'
      : '您确定要将该分类状态变更为启用吗? 启用后该分类可以录入农机';
    Modal.confirm({
      title: title,
      okText: '确认',
      cancelText: '取消',
      onOk() {
        updateMachineryType(record.typeId, { ...record, status: record.status === 1 ? 0 : 1 })
          .then((res) => {
            message.success('操作成功');
            actionRef.current.reload();
          })
          .catch((err) => {
            message.error(err);
          });
      },
    });
  };
  const handleChange = (val) => {
    setSelectModal(true);
    setTypeId(val.typeId);
    form.setFieldsValue(val);
  };

  const handleDelete = (val) => {
    deleteMachineryType(val).then(() => {
      message.success('删除成功');
      actionRef.current.reload();
    });
  };

  const Submit = (data) => {
    setLoading(true);
    if (typeId) {
      updateMachineryType(typeId, data)
        .then(() => {
          message.success(`修改成功`);
          setLoading(false);
          onCancel();
          actionRef.current.reload();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    } else {
      addMachineryType(data)
        .then(() => {
          message.success(`添加成功`);
          setLoading(false);
          onCancel();
          actionRef.current.reload();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    }
  };
  const onCancel = () => {
    form.resetFields();
    setSelectModal(false);
    setTypeId();
  };
  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => setSelectModal(true)}>
      新增农机分类
    </Button>,
  ];
  const columns = [
    {
      title: '分类名',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '创建时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: formatterTime,
      search: false,
      width: 240,
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 80,
      search: false,
      render: (_, record) => {
        return record.status === 1 ? '发布' : '未发布';
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => handleOK(record)}>
          {record.status === 0 ? '发布' : '取消发布'}
        </Button>,
        <Button style={{ padding: 0 }} type="link" key={2} onClick={() => handleChange(record)}>
          编辑
        </Button>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.typeId)}
          okText="确定"
          cancelText="取消"
        >
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];
  return (
    <PageHeaderWrapper>
      <Modal
        forceRender
        title="农机分类"
        visible={selectModal}
        onCancel={onCancel}
        destroyOnClose={true}
        footer={null}
      >
        <Form {...formItemLayout} onFinish={Submit} form={form}>
          <FormItem label="分类名" name="name">
            <Input placeholder="请输入分类名" />
          </FormItem>
          <FormItem label="状态" name="status" rules={[{ required: true, message: '请选择' }]}>
            <Select placeholder="请选择是否发布">
              <Option value={1}>发布</Option>
              <Option value={0}>未发布</Option>
            </Select>
          </FormItem>
          <FormItem label=" " colon={false}>
            <Button type="default" onClick={onCancel}>
              取消
            </Button>
            <Button
              type="primary"
              loading={loading}
              htmlType="Submit"
              style={{ marginLeft: '4em' }}
            >
              确定
            </Button>
          </FormItem>
        </Form>
      </Modal>
      <PageTable
        request={getMachineryTypeList}
        // expfunc={exportPersonList}
        toolBarRender={actions}
        actionRef={actionRef}
        columns={columns}
        rowKey="typeId"
        options={false}
        scroll={{ x: 1000 }}
      />
    </PageHeaderWrapper>
  );
};
